import xml.etree.ElementTree as ET
import json
import os

def parse_xml(xml_file):
    tree = ET.parse(xml_file)
    root = tree.getroot()
    
    # Namespace-Definition
    ns = {'ns': 'http://ard.de/sad/hfdb/vollinfo'}
    
    result = []
    id_counter = 1

    for index, vi in enumerate(root.findall('ns:VI', ns)):
        item = {'id': id_counter}
        id_counter += 1
        
        # Traegertitel
        ak_full = vi.find(".//ns:AK[@voll='j']", ns)
        if ak_full is not None:
            rhti = ak_full.find('ns:RHTI', ns)
            if rhti is not None and rhti.text:
                item['traegertitel'] = rhti.text.strip()
            else:
                print("Kein RHTI Element in AK[@voll='j'] gefunden oder leerer Text")
        else:
            print("Kein AK Element mit voll='j' gefunden")
        
        # Tracktitel
        ak = vi.find('ns:AK', ns)
        if ak is not None:
            rhti = ak.find('ns:RHTI', ns)
            if rhti is not None and rhti.text:
                item['tracktitel'] = rhti.text.strip()
            else:
                print("Kein RHTI Element in AK gefunden oder leerer Text")
        else:
            print("Kein AK Element gefunden")
        
        # Nur das erste KONF-Element verarbeiten
        konf = vi.find('.//ns:KONF', ns)
        if konf is not None:
            # Keywords
            keywords = []
            for kwe in konf.findall('.//ns:KWE/ns:TEXT', ns):
                if kwe.text:
                    keywords.append(kwe.text.strip())
            item['keywords'] = keywords
            
            # Transkript
            transcript = ""
            for speaker in konf.findall('.//ns:TRANSCRIPT/ns:SPEAKER', ns):
                if speaker.text:
                    transcript += speaker.text.strip() + " "
            item['transkript'] = transcript.strip()
        else:
            print("Kein KONF Element gefunden")

        # Link aus PLUGPARA erstellen
        plugpara = vi.find('.//ns:PLUGPARA', ns)
        if plugpara is not None:
            instance = plugpara.get('instance')
            konf = plugpara.get('konf')
            amo = plugpara.get('amo')
            ak = plugpara.get('ak')
            gk = plugpara.get('gk')
            
            link = f"https://linkresolver2.ivz.cn.ard.de/linkresolver/resolve?context=hfdb2&hfdb-recherche/permalink?typ=vollinfoAnzeige&vollinfoArt=vollinfokonf&ak={ak}&ko={konf}&amo={amo}&gkonf={gk}&destination={instance}"
            item['link'] = link
        else:
            print("Kein PLUGPARA Element gefunden")
        
        result.append(item)
    
    return result

def xml_to_json(input_file, output_dir):
    data = parse_xml(input_file)
    output_file = os.path.join(output_dir, os.path.splitext(os.path.basename(input_file))[0] + '.json')
    
    with open(output_file, 'w', encoding='utf-8') as f:
        json.dump(data, f, ensure_ascii=False, indent=2)
    
    print(f"Die JSON-Datei wurde erstellt: {output_file}")
    return output_file
